oumi.cli
========
.. py:module:: oumi.cli

Submodules
----------

oumi.cli.cli\_utils module
--------------------------

.. automodule:: oumi.cli.cli_utils
   :members:
   :undoc-members:
   :show-inheritance:

oumi.cli.distributed\_run module
--------------------------------

.. automodule:: oumi.cli.distributed_run
   :members:
   :undoc-members:
   :show-inheritance:

oumi.cli.env module
-------------------

.. automodule:: oumi.cli.env
   :members:
   :undoc-members:
   :show-inheritance:

oumi.cli.evaluate module
------------------------

.. automodule:: oumi.cli.evaluate
   :members:
   :undoc-members:
   :show-inheritance:

oumi.cli.infer module
---------------------

.. automodule:: oumi.cli.infer
   :members:
   :undoc-members:
   :show-inheritance:

oumi.cli.judge module
---------------------

.. automodule:: oumi.cli.judge
   :members:
   :undoc-members:
   :show-inheritance:

oumi.cli.launch module
----------------------

.. automodule:: oumi.cli.launch
   :members:
   :undoc-members:
   :show-inheritance:

oumi.cli.main module
--------------------

.. automodule:: oumi.cli.main
   :members:
   :undoc-members:
   :show-inheritance:

oumi.cli.train module
---------------------

.. automodule:: oumi.cli.train
   :members:
   :undoc-members:
   :show-inheritance:
